/*
	CheckSize v0.91
	(c) 2003 by Don K. Eitner

	A BLANK CD-R/RW DISC MUST BE IN YOUR RECORDER DRIVE BEFORE YOU RUN THIS SCRIPT.

	Usage:
	CheckSize Param

	IF Param is given as the number of sb_project.* files to check (the standard method for post-
	processing scripts) then CheckSize will find the ISO size for each project file already created
	by SmartBackup and compare it to the capacity of a blank CD-R/RW disc which is currently in
	your CD recorder.

	If Param is not given or is anything other than a number, then CheckSize will tell you the
	capacity of a blank CD-R/RW disc which is currently in your CD recorder.  This can be useful to
	fine-tune the DiscSize you give to SmartBackup in order to squeze every last bit of data onto
	each output disc.  THIS SHOULD ONLY BE DONE BY EXPERIENCED USERS.  OUTPUT PROJECTS CAN GROW IN
	SIZE WHEN CONVERTED TO ISO FILE SYSTEM.
*/

PARSE ARG Param

/* Load IBM Rexx utility functions */
CALL RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
CALL SysLoadFuncs

CALL SysCls

SBConf = ''
CheckDirs = 1
TempDir = Value('TEMP', , 'OS2ENVIRONMENT')

PARSE SOURCE . . ProgDir
ProgDir = Filespec('d', ProgDir)||Filespec('p', ProgDir)
ProgDir = Left(ProgDir, Lastpos('\', ProgDir) - 1)

IF DataType(Param) = 'NUM' THEN
	DO
		Mode = 'VERIFY'
		Project.0 = Param
	END

IF Translate(Mode) = 'VERIFY' THEN
	DO Num = 1 TO Project.0
		/* We need to modify the input list file so we'll create a modified copy */
		ProjectFile = TempDir||'\sb_project.'||Num
		IF Stream(ProjectFile, 'c', 'query exists') = '' THEN
			LEAVE

		ListFile = ProjectFile||'.list'

		/* Open input project file */
		RC = Stream(ProjectFile, 'c', 'open read')

		/* Read global configuration file because each project file could have its own configuration file */
		CALL GetConfFromProject
		CALL ReadConf

		/* Open output project file - to avoid problems, delete it if it already exists */
		IF Stream(ListFile, 'c', 'query exists') <> '' THEN
			RC = SysFileDelete(ListFile)
		RC = Stream(ListFile, 'c', 'open write')

		/* Copy each line from input to output, removing the file sizes from the list */
		DO While Lines(ProjectFile) > 0
			InLine = Linein(ProjectFile, , 1)
			PARSE VALUE InLine WITH Size '09'x Unit '09'x InFile
			/* If file needs to be byte split, do it now */
			IF Stream(InFile, 'c', 'query exists') = '' & Right(InFile, 3) = "001" THEN
				DO
					DiscSize = Size
					CALL bytesplit '-S -C' Size '-U' Unit '-I "'||Substr(InFile, 1, Length(InFile) - 4)||'"'
				END
			IF Stream(InFile, 'c', 'query exists') = '' & Right(InFile, 3) >= 002 & Right(InFile, 3) <= 999 THEN
				CALL bytesplit '-S -C' DiscSize '-U' Unit '-I "'||Substr(InFile, 1, Length(InFile) - 4)||'"'

			OutFile = Filespec('P', InFile)||Filespec('N', InFile)
			OutLine = Translate(OutFile, '/', '\')||'='||Translate(InFile, '/', '\')

			RC = Lineout(ListFile, OutLine)
		END

		/* Close both files */
		RC = Stream(ListFile, 'c', 'close')
		RC = Stream(ProjectFile, 'c', 'close')

		/* Clear anything currently on the RxQueue */
		DO WHILE Queued() > 0
			PULL Junk
		END

		/* Get ISO size */
		CALL GetISOSize

		/* Get CD capacity */
		CALL GetCDSize

		SAY
		SAY 'For disc' Num
		SELECT
			WHEN CDSizeKB > ISOSizeKB THEN
				SAY 'Backup will fit the disc.  Free space after =' CDSizeMB - ISOSizeMB 'MB ('||CDSizeKB - ISOSizeKB 'KB).'
			WHEN CDSizeKB < ISOSizeKB THEN
				SAY 'WARNING: Backup will not fit the disc.  Over by:' ISOSizeMB - CDSizeMB 'MB ('||ISOSizeKB - CDSizeKB 'KB).'
			WHEN CDSizeKB = ISOSizeKB THEN
				SAY 'Exact match.  One bad block on the disc could cause the backup to no fit.'
		END
	END
ELSE
	DO
		CALL GetConf
		CALL ReadConf

		/* Get CD capacity */
		CALL GetCDSize

		SAY
		SAY 'Your CD capacity is' CDSizeMB 'MB ('||CDSizeKB 'KB)'
		SAY
		SAY 'PLEASE NOTE: This is the full, unformatted capacity of the disc!  The CD file'
		SAY '   system will store additional data depending on the number and type of files'
		SAY '   you record to the disc.  You may not be able to use this full capacity for'
		SAY '   data files.  It is highly recommended that you supply SmartBackup with a'
		SAY '   slightly lower disc size, such as' Recommended 'to be safe.'
	END

EXIT


GetConfFromProject:
	InLine = Linein(ProjectFile, , 1)
	IF Translate(Left(InLine, Pos('=', InLine) - 1)) = 'SBCONF' THEN
		DO
			SBConf = Substr(InLine, Pos('=', InLine) + 1)
			IF Stream(SBConf, 'c', 'query exists') = '' THEN
				DO UNTIL Stream(SBConf, 'c', 'query exists') <> ''
					SAY 'Configuration file' SBConf 'cannot be found.'
					SAY 'Enter the full path and filename of the configuration file to use.'
					PARSE PULL SBConf
				END
		END
	ELSE
		DO
			SAY 'Invalid project file. Cannot find SBConf= on line 1.'
			/* Close input project file */
			RC = Stream(ListFile, 'c', 'close')
			EXIT
		END
RETURN


GetConf:
	/* If configuration file was not specified, use default name */
	IF SBConf = '' THEN
		DO
			SBConfGiven = 0
			SBConf = 'smartbackup.conf'
		END
	ELSE
		/* If configuration file was specified but only as a filename, note that something was given */
		IF Filespec('p', SBConf) = '' THEN
			SBConfGiven = 1
		ELSE
			/* If configuration file was specified with a full path name, note that we got it all */
			SBConfGiven = 2

	/* If we got it all, be sure the file exists */
	IF SBConfGiven = 2 THEN
		DO
			IF Stream(SBConf, 'c', 'query exists') <> '' THEN
				Found = 1
		END
	ELSE
		/* If we got nothing or only got a filename, be sure we can find it */
		DO UNTIL Found = 1 | CheckDirs > 4
			SELECT
				WHEN CheckDirs = 1 THEN
					CheckDir = ProgDir
				WHEN CheckDirs = 2 THEN
					CheckDir = CurDir
				WHEN CheckDirs = 3 THEN
					CheckDir = Value('HOME', , 'OS2ENVIRONMENT')
				WHEN CheckDirs = 4 THEN
					CheckDir = Value('ETC', , 'OS2ENVIRONMENT')
				OTHERWISE
					LEAVE
			END

			IF Right(NewDir, 1) = '\' THEN
				CheckDir = Left(CheckDir, Length(NewDir) - 1)

			IF Stream(CheckDir||'\'||SBConf, 'c', 'query exists') = '' THEN
				CheckDirs = CheckDirs + 1
			ELSE
				DO
					SBConf = CheckDir||'\'||SBConf
					Found = 1
				END
		END

	IF Found <> 1 THEN
		DO UNTIL Stream(SBConf, 'c', 'query exists') <> ''
			SAY 'Could not find' SBConf||'.'
			SAY 'Enter the full path and filename of the configuration file to use.'
			PARSE PULL SBConf
		END
	ELSE
		DO
			IF (SBConfGiven < 2) & (CheckDir <> ProgDir) & (CheckDir <> CurDir) THEN
				DO
					SAY 'I found the configuration file at' SBConf
					SAY 'Do you wish to use this configuration file? (Y/N)'
					DO UNTIL Junk = 'Y' | Junk = 'N'
						Junk = Translate(SysGetKey(NOECHO))
					END
					IF Junk = 'N' THEN
						DO UNTIL Stream(SBConf, 'c', 'query exists') <> ''
							SAY 'Enter the full path and filename of the configuration file to use.'
							PARSE PULL SBConf
						END
				END
		END
RETURN


ReadConf:
	/* Read global configuration file into variables */
	RC = Stream(SBConf, 'c', 'open read')
	DO WHILE Lines(SBConf) > 0
		InLine = Linein(SBConf, , 1)
		IF Left(InLine, 2) = '/*' | Left(InLine, 2) = '*/' | InLine = '' THEN
			ITERATE
		ELSE
			SELECT
				WHEN Translate(Left(InLine, Pos('=', InLine) - 1)) = 'ISOPROG' THEN
					ISOProg = Substr(InLine, Pos('=', InLine) + 1)
				WHEN Translate(Left(InLine, Pos('=', InLine) - 1)) = 'ISOADDITIONAL' THEN
					ISOAdditional = Substr(InLine, Pos('=', InLine) + 1)
				WHEN Translate(Left(InLine, Pos('=', InLine) - 1)) = 'CDRPROG' THEN
					CDRProg = Substr(InLine, Pos('=', InLine) + 1)
				WHEN Translate(Left(InLine, Pos('=', InLine) - 1)) = 'CDRDEVICE' THEN
					CDRDevice = 'dev='||Substr(InLine, Pos('=', InLine) + 1)
				OTHERWISE
					NOP
			END
	END
	RC = Stream(SBConf, 'c', 'close')
RETURN


GetCDSize:
	'@'||CDRProg CDRDevice '-atip | RXQUEUE'

	DO UNTIL Left(Line, 23) = 'ATIP START OF LEAD OUT:'
		PULL Line
		Line = Space(Line)
		IF Left(Line, 18) = 'CMD FINISHED AFTER' THEN
			EXIT
	END

	CDBlocks = SubStr(Line, 25, 6)
	CDSizeKB = CDBlocks * 2
	CDSizeMB = CDBlocks * 2048 / (1024**2)
	CDSizeKB = Space(Format(CDSizeKB, 9, 2))
	CDSizeMB = Space(Format(CDSizeMB, 6, 3))
RETURN


GetISOSize:
	'@'||ISOProg ISOAdditional '-print-size -path-list' ListFile '| RXQUEUE'

	PULL Line

	IF DataType(Line) = 'NUM' THEN
		ISOBlocks = Line
	ISOSizeKB = ISOBlocks * 2
	ISOSizeMB = ISOBlocks * 2048 / (1024**2)
	ISOSizeKB = Space(Format(ISOSizeKB, 9, 2))
	ISOSizeMB = Space(Format(ISOSizeMB, 6, 3))
RETURN

