/*
	pp_zip2iso.cmd v0.91
	(c) 2003 by Don Eitner

	routine to zip each sb_project to maintain long filenames and EAs, then create CD-ROM ISO images of the zips

	Usage:  pp_zip2iso.cmd Project.0
	where Project.0 is the number of sb_project.* files to process.
*/

PARSE ARG Project.0 SBConf

/* Find the system %TEMP% directory so we can be sure to locate the project files */
TempDir = Value('TEMP', , 'OS2ENVIRONMENT')
IF TempDir = '' THEN
	TempDir = Value('TMP', , 'OS2ENVIRONMENT')

/* Create each backup disc in turn */
DO Num = 1 TO Project.0
	/* We need to modify the input list file so we'll create a modified copy */
	ProjectFile = TempDir||'\sb_project.'||Num
	ListFile = ProjectFile||'.list'

	/* Open input project file */
	RC = Stream(ProjectFile, 'c', 'open read')

	/* Read global configuration file because each project file could have its own configuration file */
	CALL ReadConf

	/* Open output project file - to avoid problems, delete it if it already exists */
	IF Stream(ListFile, 'c', 'query exists') <> '' THEN
		RC = SysFileDelete(ListFile)
	RC = Stream(ListFile, 'c', 'open write')

	/* Copy each line from input to output, removing the file sizes from the list */
	DO While Lines(ProjectFile) > 0
		InLine = Linein(ProjectFile, , 1)
		PARSE VALUE InLine WITH Size '09'x Unit '09'x InFile
		/* If file needs to be byte split, do it now */
		IF Stream(InFile, 'c', 'query exists') = '' & Right(InFile, 3) = "001" THEN
			DO
				DiscSize = Size
				CALL bytesplit '-S -C' Size '-U' Unit '-I "'||Substr(InFile, 1, Length(InFile) - 4)||'"'
			END
		IF Stream(InFile, 'c', 'query exists') = '' & Right(InFile, 3) >= 002 & Right(InFile, 3) <= 999 THEN
			CALL bytesplit '-S -C' DiscSize '-U' Unit '-I "'||Substr(InFile, 1, Length(InFile) - 4)||'"'

		OutLine = InFile
		RC = Lineout(Listfile, OutLine)
	END

	/* Close both files */
	RC = Stream(ListFile, 'c', 'close')
	RC = Stream(ProjectFile, 'c', 'close')

	/* Create the temporary zip compressed file which will be burned to CD */
	VolumeName = VolumeID||'_'||Num||'of'||Project.0
	ZipFile = OutputDir||'/'||VolumeName
	SAY 'Please wait - compressing project #' Num
	'@type' ListFile '| zip -9' ZipFile||'.zip -@'

	/* Now record it to the CD */
	SAY 'Please wait, creating CD image for project #' Num

	/************************************************************************************************/
	/* For debugging/testing purposes, exchange the following line (remarked out) for the one below */
	/************************************************************************************************/
/*
	'@'||ISOProg '-V' VolumeName ISOAdditional '-o "'||ZipFile||'.iso"' ZipFile||'.zip'
*/
	'@'||ISOProg '-V' VolumeName ISOAdditional ZipFile||'.zip |' CDRProg CDRDevice CDRSpeed CDRBuffer CDRAdditional '-'

	/* Cleanup/delete temporary files */
	RC = SysFileDelete(ListFile)
	RC = SysFileDelete(ZipFile||'.zip')

	/* Prompt user for next CD in a multiple-CD set */
	IF Project.0 > Num THEN
		DO
			SAY 'Time to remove that disc and add the next ('||Num+1||'). Press ENTER when ready.'
			PAUSE
		END
END

EXIT


ReadConf:
	InLine = Linein(ProjectFile, , 1)
	IF Translate(Left(InLine, Pos('=', InLine) - 1)) = 'SBCONF' THEN
		DO
			SBConf = Substr(InLine, Pos('=', InLine) + 1)
			IF Stream(SBConf, 'c', 'query exists') = '' THEN
				DO UNTIL Stream(SBConf, 'c', 'query exists') <> ''
					SAY 'Configuration file' SBConf 'cannot be found.'
					SAY 'Enter the full path and filename of the configuration file to use.'
					PARSE PULL SBConf
				END
		END
	ELSE
		DO
			SAY 'Invalid project file. Cannot find SBConf= on line 1.'
			/* Close input project file */
			RC = Stream(ListFile, 'c', 'close')
			EXIT
		END

	/* Read global configuration file into variables */
	RC = Stream(SBConf, 'c', 'open read')
	DO WHILE Lines(SBConf) > 0
		InLine = Linein(SBConf, , 1)
		IF Left(InLine, 2) = '/*' | Left(InLine, 2) = '*/' | InLine = '' THEN
	     	ITERATE
		ELSE
			SELECT
				WHEN Translate(Left(InLine, Pos('=', InLine) - 1)) = 'OUTPUTDIR' THEN
					OutputDir = Substr(InLine, Pos('=', InLine) + 1)
				WHEN Translate(Left(InLine, Pos('=', InLine) - 1)) = 'VOLUMEID' THEN
					VolumeID = Substr(InLine, Pos('=', InLine) + 1)
				WHEN Translate(Left(InLine, Pos('=', InLine) - 1)) = 'ISOPROG' THEN
					ISOProg = Substr(InLine, Pos('=', InLine) + 1)
				WHEN Translate(Left(InLine, Pos('=', InLine) - 1)) = 'ISOADDITIONAL' THEN
					ISOAdditional = Substr(InLine, Pos('=', InLine) + 1)
				WHEN Translate(Left(InLine, Pos('=', InLine) - 1)) = 'CDRPROG' THEN
					CDRProg = Substr(InLine, Pos('=', InLine) + 1)
				WHEN Translate(Left(InLine, Pos('=', InLine) - 1)) = 'CDRSPEED' THEN
					CDRSpeed = 'speed='||Substr(InLine, Pos('=', InLine) + 1)
				WHEN Translate(Left(InLine, Pos('=', InLine) - 1)) = 'CDRDEVICE' THEN
					CDRDevice = 'dev='||Substr(InLine, Pos('=', InLine) + 1)
				WHEN Translate(Left(InLine, Pos('=', InLine) - 1)) = 'CDRBUFFER' THEN
					CDRBuffer = 'fs='||Substr(InLine, Pos('=', InLine) + 1)
				WHEN Translate(Left(InLine, Pos('=', InLine) - 1)) = 'CDRADDITIONAL' THEN
					CDRAdditional = Substr(InLine, Pos('=', InLine) + 1)
				OTHERWISE
					NOP
			END
	END
	RC = Stream(SBConf, 'c', 'close')
RETURN

